CUDA: fix bug in topk-moe softmax (llama/16711)

This commit is contained in:
Aman Gupta
2025-11-09 23:38:03 +02:00
committed by Georgi Gerganov
parent ba41a6ca6a
commit 431aaf56f0
+1 -1
View File
@@ -141,7 +141,7 @@ __launch_bounds__(4 * WARP_SIZE, 1) __global__ void topk_moe_cuda(const float *
wt_sum = warp_reduce_sum(wt_sum);
const float inv_sum = 1.0f / wt_sum;
for (int i = threadIdx.x; i < n_expert_used; i += WARP_SIZE) {
for (int i = 0; i < experts_per_thread; i++) {
output_weights[i] *= inv_sum;
}
}